pub enum EmbedderControl {
SelectElement(SelectElement),
ColorPicker(ColorPicker),
FilePicker(FilePicker),
InputMethod(InputMethodControl),
SimpleDialog(SimpleDialog),
ContextMenu(ContextMenu),
}Expand description
The controls of an interactive form element.
Variants
SelectElement(SelectElement)
The picker of a <select> element.
ColorPicker(ColorPicker)
The picker of a <input type=color> element.
FilePicker(FilePicker)
The picker of a <input type=file> element.
InputMethod(InputMethodControl)
Request to present an input method (IME) interface to the user when an editable element is focused.
SimpleDialog(SimpleDialog)
A simple dialog initiated by
script (alert(), confirm(), or prompt()). Since their messages are controlled by web
content, they should be presented to the user in a way that makes them impossible to
mistake for browser UI.
ContextMenu(ContextMenu)
A context menu. This can be triggered by things like right-clicking on web content. The menu that is actually shown the user may be customized, but custom menu entries must be handled by the embedder.
Implementations
Sourceimpl EmbedderControl
impl EmbedderControl
Sourcepub fn id(&self) -> EmbedderControlId
pub fn id(&self) -> EmbedderControlId
Return the unique identifier for this embedder control.