pub enum WebViewRect {
Device(Box2D<f32, DevicePixel>),
Page(Box2D<f32, CSSPixel>),
}Expand description
A rectangle in a WebView, either expressed in device pixels or page pixels.
Page pixels are CSS pixels, which take into account device pixel scale,
page zoom, and pinch zoom.
Variants