pub struct AllowOrDenyRequest(IpcResponder<AllowOrDeny>, ServoErrorSender);Expand description
A type used for communicating an allow-or-deny decision from the embedder to Servo. This is used as a part of requests from Servo to the embedder to perform certain actions and the request can either be allowed or denied by the embedder.
Tuple Fields
0: IpcResponder<AllowOrDeny>1: ServoErrorSenderImplementations
Sourceimpl AllowOrDenyRequest
impl AllowOrDenyRequest
pub(crate) fn new( response_sender: GenericSender<AllowOrDeny>, default_response: AllowOrDeny, error_sender: ServoErrorSender, ) -> Self
pub(crate) fn new_from_callback( callback: GenericCallback<AllowOrDeny>, default_response: AllowOrDeny, error_sender: ServoErrorSender, ) -> Self