pub struct BluetoothDeviceSelectionRequest {
devices: Vec<BluetoothDeviceDescription>,
responder: IpcResponder<Option<String>>,
}Expand description
A request to let the user chose a Bluetooth device.
Fields
devices: Vec<BluetoothDeviceDescription>responder: IpcResponder<Option<String>>Implementations
Sourceimpl BluetoothDeviceSelectionRequest
impl BluetoothDeviceSelectionRequest
pub(crate) fn new( devices: Vec<BluetoothDeviceDescription>, responder: GenericSender<Option<String>>, ) -> Self
Sourcepub fn pick_device(
self,
device: &BluetoothDeviceDescription,
) -> Result<(), SendError>
pub fn pick_device( self, device: &BluetoothDeviceDescription, ) -> Result<(), SendError>
Set the device chosen by the user.
Sourcepub fn devices(&self) -> &Vec<BluetoothDeviceDescription>
pub fn devices(&self) -> &Vec<BluetoothDeviceDescription>
The set of devices that the user can chose from.