InputMethodControl

Struct InputMethodControl 

pub struct InputMethodControl {
    pub(crate) id: EmbedderControlId,
    pub(crate) input_method_type: InputMethodType,
    pub(crate) text: String,
    pub(crate) insertion_point: Option<u32>,
    pub(crate) position: DeviceIntRect,
    pub(crate) multiline: bool,
    pub(crate) allow_virtual_keyboard: bool,
}
Represents a request to enable the system input method interface.

Fields

id: EmbedderControlIdinput_method_type: InputMethodTypetext: Stringinsertion_point: Option<u32>position: DeviceIntRectmultiline: boolallow_virtual_keyboard: bool

Implementations

Source

impl InputMethodControl

pub fn input_method_type(&self) -> InputMethodType

Return the type of input method that initated this request.

pub fn text(&self) -> String

Return the current string value of the input field.

pub fn insertion_point(&self) -> Option<u32>

The current zero-based insertion point / cursor position if it is within the field or None if it is not.

pub fn position(&self) -> DeviceIntRect

Get the area occupied by the <input> element that triggered the input method.

The embedder should use this value to position the input method interface that is shown to the user.

pub fn multiline(&self) -> bool

Whether or not this field is a multiline field.

pub fn allow_virtual_keyboard(&self) -> bool

Whether the virtual keyboard should be shown for this input method event. This is currently true for input method events that happen after the user has interacted with page contents via an input event.