pub struct NetworkManager {
public_resource_threads: ResourceThreads,
private_resource_threads: ResourceThreads,
}Expand description
Provides APIs for managing network-related state.
NetworkManager is responsible for data owned by the networking layer,
such as the HTTP cache. This data is not considered site data and is
therefore intentionally separate from SiteDataManager.
Fields
public_resource_threads: ResourceThreadsprivate_resource_threads: ResourceThreadsImplementations
Sourceimpl NetworkManager
impl NetworkManager
pub(crate) fn new( public_resource_threads: ResourceThreads, private_resource_threads: ResourceThreads, ) -> Self
Sourcepub fn cache_entries(&self) -> Vec<CacheEntry>
pub fn cache_entries(&self) -> Vec<CacheEntry>
Returns cache entries currently stored in the HTTP cache.
The returned list contains one CacheEntry per unique cache key
(URL) for which the networking layer currently maintains cached
responses.
Both public and private browsing contexts are included in the result.
Note: The networking layer currently only implements an in-memory HTTP cache. Support for an on-disk cache is under development.
Sourcepub fn clear_cache(&self)
pub fn clear_cache(&self)
Clears the network (HTTP) cache.
This removes all cached network responses maintained by the networking layer for both public and private browsing contexts.
Note: The networking layer currently only implements an in-memory HTTP cache. Support for an on-disk cache is under development.