pub struct PermissionRequest {
pub(crate) requested_feature: PermissionFeature,
pub(crate) allow_deny_request: AllowOrDenyRequest,
}Expand description
A permissions request for a WebView. The embedder should allow or deny the request,
either by reading a cached value or querying the user for permission via the user
interface.
Fields
requested_feature: PermissionFeatureallow_deny_request: AllowOrDenyRequestImplementations
Sourceimpl PermissionRequest
impl PermissionRequest
Sourcepub fn feature(&self) -> PermissionFeature
pub fn feature(&self) -> PermissionFeature
Get the PermissionFeature for which permission is being requested by page content.