pub struct WebViewBuilder {
servo: Servo,
rendering_context: Rc<dyn RenderingContext>,
delegate: Rc<dyn WebViewDelegate>,
url: Option<Url>,
hidpi_scale_factor: Scale<f32, DeviceIndependentPixel, DevicePixel>,
create_new_webview_responder: Option<IpcResponder<Option<NewWebViewDetails>>>,
user_content_manager: Option<Rc<UserContentManager>>,
clipboard_delegate: Option<Rc<dyn ClipboardDelegate>>,
gamepad_delegate: Option<Rc<dyn GamepadDelegate>>,
}Expand description
Builder for creating a WebView.
Fields
servo: Servorendering_context: Rc<dyn RenderingContext>delegate: Rc<dyn WebViewDelegate>url: Option<Url>hidpi_scale_factor: Scale<f32, DeviceIndependentPixel, DevicePixel>create_new_webview_responder: Option<IpcResponder<Option<NewWebViewDetails>>>user_content_manager: Option<Rc<UserContentManager>>clipboard_delegate: Option<Rc<dyn ClipboardDelegate>>gamepad_delegate: Option<Rc<dyn GamepadDelegate>>Implementations
Sourceimpl WebViewBuilder
impl WebViewBuilder
Sourcepub fn new(servo: &Servo, rendering_context: Rc<dyn RenderingContext>) -> Self
pub fn new(servo: &Servo, rendering_context: Rc<dyn RenderingContext>) -> Self
Create a WebViewBuilder that can be used to configure and create a WebView.
The new WebView will be managed by the given servo instance and will
use rendering_context to paint its contents.
pub(crate) fn new_for_create_request( servo: &Servo, rendering_context: Rc<dyn RenderingContext>, responder: IpcResponder<Option<NewWebViewDetails>>, ) -> Self
Sourcepub fn delegate(self, delegate: Rc<dyn WebViewDelegate>) -> Self
pub fn delegate(self, delegate: Rc<dyn WebViewDelegate>) -> Self
Set the WebViewDelegate that will receive notifications about the events
in the WebView being created.
Sourcepub fn hidpi_scale_factor(
self,
hidpi_scale_factor: Scale<f32, DeviceIndependentPixel, DevicePixel>,
) -> Self
pub fn hidpi_scale_factor( self, hidpi_scale_factor: Scale<f32, DeviceIndependentPixel, DevicePixel>, ) -> Self
Set the initial HiDPI scale factor for the WebView being created.
Sourcepub fn user_content_manager(
self,
user_content_manager: Rc<UserContentManager>,
) -> Self
pub fn user_content_manager( self, user_content_manager: Rc<UserContentManager>, ) -> Self
Set the UserContentManager for the WebView being created. The same
UserContentManager can be shared among multiple WebViews. Any updates
to the UserContentManager will take effect only after the document is reloaded.
Sourcepub fn clipboard_delegate(
self,
clipboard_delegate: Rc<dyn ClipboardDelegate>,
) -> Self
pub fn clipboard_delegate( self, clipboard_delegate: Rc<dyn ClipboardDelegate>, ) -> Self
Set the ClipboardDelegate for the WebView being created. The same
ClipboardDelegate can be shared among multiple WebViews.
Sourcepub fn gamepad_delegate(self, gamepad_delegate: Rc<dyn GamepadDelegate>) -> Self
pub fn gamepad_delegate(self, gamepad_delegate: Rc<dyn GamepadDelegate>) -> Self
Set the GamepadDelegate for the WebView being created. The same
GamepadDelegate can be shared among multiple WebViews.
Sourcepub fn build(self) -> WebView
pub fn build(self) -> WebView
Create the WebView using the configuration specified in this WebViewBuilder.