pub fn should_panic_hook_suppress_termination() -> boolExpand description
Returns true if embedder’s custom panic hook handler should not treat the panic
as a fatal error that requires termination of the engine.
This is needed to catch and silence panics in resvg crate. servoshell registers a custom panic hook that aborts the process in hard_failmode even when usingcatch_unwind`.